Clustering.All.Rate: Conduct cell clustering on mutiple datasets and removal rates

View source: R/Downstream.R

Clustering.All.RateR Documentation

Conduct cell clustering on mutiple datasets and removal rates

Description

Conduct Louvin Clustering on datasets generated with different doublet removal rates and doublet-detection methods.

Usage

Clustering.All.Rate(data.removal.all.rate)

Arguments

data.removal.all.rate

A list of scRNA-seq data matrices after removing doublets by different methods with different removal rates.

Value

A list of clustering result (number of clusters) under different removal rates.

Examples

result.cluster.all.rate <- Clustering.All.Rate(data.removal.all.rate)


xnnba1984/DoubletCollection documentation built on Dec. 10, 2022, 11:13 a.m.