Clustering.Quality: Calculate singlet rates

View source: R/Downstream.R

Clustering.QualityR Documentation

Calculate singlet rates

Description

Calculate singlet rates in correctly identified clusters for different doublet-detection methods.

Usage

Clustering.Quality(
  table.cluster,
  result.cluster.all.rate,
  data.removal.all.rate
)

Arguments

table.cluster

A data frame with clustering result.

result.cluster.all.rate

A list of clustering result (number of clusters) under different removal rates.

data.removal.all.rate

A list of scRNA-seq data matrices after removing doublets by different methods with different removal rates.

Value

A data frame with singlet rates in each correctly identified cluster.

Examples

table.cluster.quality <- Clustering.Quality(table.cluster, result.cluster.all.rate, data.removal.all.rate)


xnnba1984/DoubletCollection documentation built on Dec. 10, 2022, 11:13 a.m.