FindDistributedAUC.All: Calculate detection accuracy under distributed computing

View source: R/Downstream.R

FindDistributedAUC.AllR Documentation

Calculate detection accuracy under distributed computing

Description

Randomly split one dataset into user-specified batches. Perform doublet detection on each batch by different methods to calculate doublet scores. Concatenate doublet scores per batch. Calclulate AUPRC or AUROC on concatenated doublet scores.

Usage

FindDistributedAUC.All(count, label, method, batches, type)

Arguments

count

A scRNA-seq data matrix.

label

A vector of doublet annotations (0/1).

batches

A vector of batch numbers.

type

A string of measurement "AUPRC" or "AUROC".

Value

A list of measurement across different batch numbers and methods.

Examples

data.list <- ReadData(path = ".../real_datasets")
count <- data.list$count$`pbmc-ch`
label <- data.list$label$`pbmc-ch`
label <- ifelse(label == 'doublet', 1, 0)
auc.list.batch <- FindDistributedAUC.All(count = count, label = label, method=methods, batches = 2:10, type='AUPRC')


xnnba1984/DoubletCollection documentation built on Dec. 10, 2022, 11:13 a.m.