RemoveDoublets: Remove doublets for single method on single dataset

View source: R/FindDoublets.R

RemoveDoubletsR Documentation

Remove doublets for single method on single dataset

Description

Remove doublets based on identified doublet indices for single method on single dataset.

Usage

RemoveDoublets(count, label, doublets)

Arguments

count

A scRNA-seq data matrix.

label

A vector of cell type annotations.

doublets

A vector of identified doublet indices.

Value

A list of scRNA-seq data matrix and cell type annotations after removing doublets.


xnnba1984/DoubletCollection documentation built on Dec. 10, 2022, 11:13 a.m.