| RemoveDoublets.All.Rate | R Documentation |
Remove doublets based on identified doublet indices for different doublet-detection methods on multiple datasets and doublet rates.
RemoveDoublets.All.Rate(count.list, label.list, doublet.list.all.rate)
count.list |
A list of scRNA-seq count matrices. |
label.list |
A list doublet annoations (0/1). |
doublet.list.all.rate |
A list of identified doublet indices of different methods on multiple datasets and doublet rates. |
A list of scRNA-seq count matrices and doublet annotations after removing doublets based on multiple doublet rates.
doublet.list.all.rate <- FindDoublets.All.Rate(score.list.all = score.list.all, rates = seq(0.01, 0.25, 0.01))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.