RemoveDoublets.Method: Remove doublets for multiple methods on single dataset

View source: R/FindDoublets.R

RemoveDoublets.MethodR Documentation

Remove doublets for multiple methods on single dataset

Description

Remove doublets based on identified doublet indices for multiple methods on single dataset.

Usage

RemoveDoublets.Method(count, label, doublet.list)

Arguments

count

A scRNA-seq data matrix.

label

A vector of cell type annotations.

doublet.list

A list of identified doublet indices of different methods.

Value

A list of scRNA-seq data matrix and cell type annotations after removing doublets by different methods.

Examples

data.removal.list <- RemoveDoublets.Method(count = data.de$count, label = data.de$label.cluster, doublet.list = doublet.list)


xnnba1984/DoubletCollection documentation built on Dec. 10, 2022, 11:13 a.m.