| RemoveDoublets.all | R Documentation |
Remove doublets based on identified doublet indices for different doublet-detection methods on multiple datasets.
RemoveDoublets.all(count.list, label.list, doublet.list.all)
count.list |
A list of scRNA-seq count matrices. |
label.list |
A list doublet annoations (0/1). |
doublet.list.all |
A list of identified doublet indices of different methods on multiple datasets. |
A list of scRNA-seq count matrices and doublet annotations after removing doublets.
data.removal.all <- RemoveDoublets.All(count.list=count.list, label.list=label.list, doublet.list.all=doublet.list.all)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.