| Clustering.All.Rate | R Documentation |
Conduct Louvin Clustering on datasets generated with different doublet removal rates and doublet-detection methods.
Clustering.All.Rate(data.removal.all.rate)
data.removal.all.rate |
A list of scRNA-seq data matrices after removing doublets by different methods with different removal rates. |
A list of clustering result (number of clusters) under different removal rates.
result.cluster.all.rate <- Clustering.All.Rate(data.removal.all.rate)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.