| Clustering.Quality | R Documentation |
Calculate singlet rates in correctly identified clusters for different doublet-detection methods.
Clustering.Quality( table.cluster, result.cluster.all.rate, data.removal.all.rate )
table.cluster |
A data frame with clustering result. |
result.cluster.all.rate |
A list of clustering result (number of clusters) under different removal rates. |
data.removal.all.rate |
A list of scRNA-seq data matrices after removing doublets by different methods with different removal rates. |
A data frame with singlet rates in each correctly identified cluster.
table.cluster.quality <- Clustering.Quality(table.cluster, result.cluster.all.rate, data.removal.all.rate)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.