| FindDistributedAUC.All | R Documentation |
Randomly split one dataset into user-specified batches. Perform doublet detection on each batch by different methods to calculate doublet scores. Concatenate doublet scores per batch. Calclulate AUPRC or AUROC on concatenated doublet scores.
FindDistributedAUC.All(count, label, method, batches, type)
count |
A scRNA-seq data matrix. |
label |
A vector of doublet annotations (0/1). |
batches |
A vector of batch numbers. |
type |
A string of measurement "AUPRC" or "AUROC". |
A list of measurement across different batch numbers and methods.
data.list <- ReadData(path = ".../real_datasets") count <- data.list$count$`pbmc-ch` label <- data.list$label$`pbmc-ch` label <- ifelse(label == 'doublet', 1, 0) auc.list.batch <- FindDistributedAUC.All(count = count, label = label, method=methods, batches = 2:10, type='AUPRC')
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.