| RemoveDoublets | R Documentation |
Remove doublets based on identified doublet indices for single method on single dataset.
RemoveDoublets(count, label, doublets)
count |
A scRNA-seq data matrix. |
label |
A vector of cell type annotations. |
doublets |
A vector of identified doublet indices. |
A list of scRNA-seq data matrix and cell type annotations after removing doublets.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.