| RemoveDoublets.Method | R Documentation |
Remove doublets based on identified doublet indices for multiple methods on single dataset.
RemoveDoublets.Method(count, label, doublet.list)
count |
A scRNA-seq data matrix. |
label |
A vector of cell type annotations. |
doublet.list |
A list of identified doublet indices of different methods. |
A list of scRNA-seq data matrix and cell type annotations after removing doublets by different methods.
data.removal.list <- RemoveDoublets.Method(count = data.de$count, label = data.de$label.cluster, doublet.list = doublet.list)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.